@@ -1,6 +1,6 @@
-package Bundle::Bugzilla;
+	package Bundle::Bugzilla;
 
-$VERSION = '0.11';
+$VERSION = '0.12';
 
 1;
 
@@ -26,9 +26,11 @@ Data::Dumper
 
 Date::Format 2.21
 
+DBI 1.38
+
 Bundle::DBD::mysql
 
-File::Spec 0.82
+File::Spec 0.84
 
 File::Temp
 
@@ -36,6 +38,14 @@ Template 2.08
 
 Text::Wrap
 
+Mail::Mailer 1.67
+
+Storable
+
+MIME::Parser
+
+MIME::Base64
+
 =head1 DESCRIPTION
 
 This bundle installs the prerequisites for Bugzilla.
@@ -43,11 +53,12 @@ This bundle installs the prerequisites for Bugzilla.
 After installing this bundle, it is recommended that you run the magic 
 checksetup.pl script to check that all modules are in place and setup 
 the tables in the database. Then, you will need to edit the file called 
-'localconfig' with your settings for bugzilla. After this, log in to 
+'localconfig' with your settings. After this, log in to 
 your installation and make yourself an account. Run checksetup.pl again 
-and you will become the superuser for your bugzilla installation. Still 
-confused? Read the information in the docs/ directory for more
-information.
+and you will become the superuser for your bugzilla installation. 
+
+Still confused? Read the information in the docs/ directory in the Bugzilla 
+distribution for more information on the installation process.
 
 =head1 AUTHOR
 
